@@ -5,10 +5,11 @@ use base 'PDF::API2::Resource::ColorSpace';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.037'; # VERSION
 
 use PDF::API2::Basic::PDF::Utils;
 use PDF::API2::Util;
+use Scalar::Util qw(weaken);
 
 sub new {
     my ($class,$pdf,$key,@opts)=@_;
@@ -20,6 +21,7 @@ sub new {
     my $self=$class->SUPER::new($pdf,$key);
     $pdf->new_obj($self) unless($self->is_obj($pdf));
     $self->{' apipdf'}=$pdf;
+    weaken $self->{' apipdf'};
 
     my $fct=PDFDict();
 
@@ -76,15 +78,6 @@ sub new {
     return($self);
 }
 
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},pdfkey(),@opts);
-    $obj->{' api'}=$api;
-
-    return($obj);
-}
-
 sub param {
     my $self=shift @_;
     return(@_);
