@@ -1,21 +1,24 @@
 package PDF::API2::Resource::ColorSpace::Indexed::Hue;
 
-our $VERSION = '2.023'; # VERSION
-
 use base 'PDF::API2::Resource::ColorSpace::Indexed';
 
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.037'; # VERSION
+
 use PDF::API2::Basic::PDF::Utils;
 use PDF::API2::Util;
-
-no warnings qw[ deprecated recursion uninitialized ];
+use Scalar::Util qw(weaken);
 
 sub new {
     my ($class,$pdf)=@_;
 
     $class = ref $class if ref $class;
-    $self=$class->SUPER::new($pdf,pdfkey());
+    my $self=$class->SUPER::new($pdf,pdfkey());
     $pdf->new_obj($self) unless($self->is_obj($pdf));
     $self->{' apipdf'}=$pdf;
+    weaken $self->{' apipdf'};
     my $csd=PDFDict();
     $pdf->new_obj($csd);
     $csd->{Filter}=PDFArray(PDFName('FlateDecode'));
