@@ -5,7 +5,7 @@ use base 'PDF::API2::Resource';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.037'; # VERSION
 
 use PDF::API2::Basic::PDF::Utils;
 use PDF::API2::Util;
@@ -31,21 +31,6 @@ sub new {
     return($self);
 }
 
-=item $font = PDF::API2::Resource::ExtGState->new_api $api, $name
-
-Returns a egstate-font object. This method is different from 'new' that
-it needs an PDF::API2-object rather than a Text::PDF::File-object.
-
-=cut
-
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},@opts);
-
-    return($obj);
-}
-
 =item $egs->strokeadjust $boolean
 
 =cut
@@ -363,15 +348,6 @@ sub opacity {
     return($self);
 }
 
-sub outobjdeep {
-    my ($self, @opts) = @_;
-    foreach my $k (qw/ api apipdf /) {
-        $self->{" $k"}=undef;
-        delete($self->{" $k"});
-    }
-    $self->SUPER::outobjdeep(@opts);
-}
-
 =back
 
 =cut
