@@ -1,8 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::courieroblique;
 
-our $VERSION = '2.023'; # VERSION
+use strict;
+use warnings;
 
-$FONTDATA = {
+our $VERSION = '2.037'; # VERSION
+
+sub data { return {
     'fontname' => 'Courier-Oblique',
     'type' => 'Type1',
     'apiname' => 'CoIt',
@@ -510,4 +513,6 @@ $FONTDATA = {
         'fi' => '600',                           # U+0xFB01
         'fl' => '600',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
-};
+} };
+
+1;
