@@ -1,8 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::verdanaitalic;
 
-our $VERSION = '2.025'; # VERSION
+use strict;
+use warnings;
 
-$FONTDATA = {
+our $VERSION = '2.037'; # VERSION
+
+sub data { return {
     'fontname' => 'Verdana,Italic',
     'type' => 'TrueType',
     'apiname' => 'VeIt',
@@ -837,4 +840,6 @@ $FONTDATA = {
         'fi' => '625',                           # U+0xFB01
         'fl' => '625',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
-};
+} };
+
+1;
