@@ -5,7 +5,7 @@ use base 'PDF::API2::Resource::XObject';
 use strict;
 use warnings;
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.037'; # VERSION
 
 use PDF::API2::Basic::PDF::Utils;
 
@@ -33,9 +33,6 @@ sub new {
     return $self;
 }
 
-# Deprecated (rolled into new)
-sub new_api { my $self = shift(); return $self->new(@_); }
-
 =item ($llx, $lly, $urx, $ury) = $form->bbox($llx, $lly, $urx, $ury)
 
 Get or set the coordinates of the form object's bounding box
