@@ -5,10 +5,11 @@ use base 'PDF::API2::Resource::XObject::Image';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.037'; # VERSION
 
 use PDF::API2::Util;
 use PDF::API2::Basic::PDF::Utils;
+use Scalar::Util qw(weaken);
 
 sub new {
     my ($class,$pdf,$obj,$name,@opts) = @_;
@@ -20,21 +21,13 @@ sub new {
     $pdf->new_obj($self) unless($self->is_obj($pdf));
 
     $self->{' apipdf'}=$pdf;
+    weaken $self->{' apipdf'};
 
     $self->read_gd($obj,@opts);
 
     return($self);
 }
 
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},@opts);
-    $obj->{' api'}=$api;
-
-    return($obj);
-}
-
 sub read_gd {
     my $self = shift @_;
     my $gd = shift @_;
